#ifndef DUNE_IDENTITY_GRID_ENTITY_SEED_HH
#define DUNE_IDENTITY_GRID_ENTITY_SEED_HH

/**
 * \file
 * \brief The IdentityGridEntitySeed class
 */


namespace Dune {


/**
 * \brief The EntitySeed class provides the minimal information needed to restore an Entity using the grid.
 * \ingroup IdentityGrid
 *
 */
template<int codim, class GridImp>
class IdentityGridEntitySeed
{
    protected:

        // Entity type of the hostgrid
        typedef typename GridImp::HostGridType::Traits::template Codim<codim>::Entity HostEntity;

        // EntitySeed type of the hostgrid
        typedef typename GridImp::HostGridType::Traits::template Codim<codim>::EntitySeed HostEntitySeed;

    public:

        enum {codimension = codim};

        /**
         * \brief Create EntitySeed from hostgrid Entity
         *
         * We call hostEntity.seed() directly in the constructor
         * of IdentityGridEntitySeed to allow for return value optimization.
         */
        IdentityGridEntitySeed(const HostEntity& hostEntity) :
            hostEntitySeed_(hostEntity.seed())
        {}

        /**
         * \brief Get stored HostEntitySeed
         */
        const HostEntitySeed& hostEntitySeed() const
        {
            return hostEntitySeed_;
        }

    private:

        HostEntitySeed hostEntitySeed_;
};

} // namespace Dune

#endif  // #define DUNE_IDENTITY_GRID_ENTITY_SEED_HH
